pub enum RenderError {
UnclosedBinding {
expr: String,
context: String,
},
UnclosedUnescapedBinding {
expr: String,
context: String,
},
EmptyBinding {
context: String,
},
MissingState {
binding: String,
context: String,
},
UnclosedDirective {
tag: String,
context: String,
},
MissingValueAttribute {
tag: String,
context: String,
},
InvalidRepeatExpression {
expr: String,
context: String,
},
NotAnArray {
binding: String,
context: String,
},
JsonParse {
message: String,
},
DuplicateTemplate {
element: String,
paths: Vec<String>,
},
TemplateReadError {
path: String,
message: String,
},
}Expand description
An error encountered while rendering a FAST HTML template.
Variants
UnclosedBinding
{{expr with no closing }}.
UnclosedUnescapedBinding
{{{expr with no closing }}}.
EmptyBinding
{{}} — the expression between {{ and }} is empty.
MissingState
{{key}} — key is not present in the provided state.
UnclosedDirective
A directive (<f-when> / <f-repeat>) has no matching closing tag.
MissingValueAttribute
A directive is missing a valid value="{{…}}" attribute.
InvalidRepeatExpression
<f-repeat value="{{expr}}"> — expression is not in item in list format.
NotAnArray
<f-repeat> binding resolves to a value that is not a JSON array.
JsonParse
The state string passed to render_template is not valid JSON.
DuplicateTemplate
Two or more template files resolve to the same element name.
TemplateReadError
A template file could not be read from the filesystem.